@@ -19,17 +19,13 @@
 #define KOPETE_AVATARFROMWEBCAMDIALOG_H
 
 // KDE includes
-#include <kdialog.h>
+#include <QDialog>
 
 // Kopete includes
-#include <kopete_export.h>
-
-namespace Kopete
-{
-
-namespace UI
-{
+#include <libkopete_export.h>
 
+namespace Kopete {
+namespace UI {
 /**
  * @brief Dialog to get a pixmap from the webcam to be set as avatar
  *
@@ -38,52 +34,49 @@ namespace UI
  * @code
 Kopete::UI::AvatarFromWebcamDialog *dialog = new Kopete::UI::AvatarFromWebcamDialog();
 int result = dialog->exec();
-if( result == KDialog::Ok ) {
+if( result == QDialog::Ok ) {
    QPixmap pixmap = dialog->getLastPixmap();
 }
  * @endcode
  *
  * @author Alex Fiestas <alex@eyeos.org>
  */
-class KOPETE_EXPORT AvatarWebcamDialog : public KDialog
+class LIBKOPETE_EXPORT AvatarWebcamDialog : public QDialog
 {
-	Q_OBJECT
+    Q_OBJECT
 public:
-	/**
-	 * Create a new AvatarFromWebcamDialog
-	 * @param parent Parent widget
-	 */
-	AvatarWebcamDialog(QWidget *parent = 0);
-	/**
-	 * Clean-up resource of AvatarFromWebcamDialog
-	 */
-	virtual ~AvatarWebcamDialog();
-	/**
-	 * Return the last captured pixmap
-	 */
-	QPixmap& getLastPixmap();
+    /**
+     * Create a new AvatarFromWebcamDialog
+     * @param parent Parent widget
+     */
+    AvatarWebcamDialog(QWidget *parent = nullptr);
+    /**
+     * Clean-up resource of AvatarFromWebcamDialog
+     */
+    virtual ~AvatarWebcamDialog();
+    /**
+     * Return the last captured pixmap
+     */
+    QPixmap &getLastPixmap();
 
 private Q_SLOTS:
-	/**
-	*Internal use, updates the webcamwidget image
-	*/
-	void updateImage();
+    /**
+    *Internal use, updates the webcamwidget image
+    */
+    void updateImage();
 
 protected Q_SLOTS:
 
-	/**
-	 * @internal
-	 * A button has been clicked. Reimplemented from @ref KDialog::slotButtonClicked()
-	 */
-	virtual void slotButtonClicked(int button);
+    /**
+     * @internal
+     * A button has been clicked. Reimplemented from @ref QDialog::slotButtonClicked()
+     */
+    virtual void slotButtonClicked(int button);
 
 private:
-	class Private;
-	Private * const d;
+    class Private;
+    Private *const d;
 };
-
 } // namespace UI
-
 } // namespace Kopete
 #endif
-
